@@ -16,7 +16,6 @@
 
 namespace Ui {
     class MainWindow;
-    //class MainWindowVert;
 }
 
 class MainWindow : public QMainWindow {
@@ -50,7 +49,6 @@ protected:
 
 private:
     Ui::MainWindow *ui;
-    //Ui::MainWindowVert *uiVert;
     void fromClipboard(int);
     void toClipboard(int);
     void initLangCodes();
@@ -58,7 +56,6 @@ private:
     QHttp *_http;
     QBuffer *_translation;
     int _toWindow;
-    bool inResizeEvent;
 
 private slots:
     void translateRequestFinished(int requestId, bool error);
